import pathlib
from os.path import exists


class SlangConverterMachine:
  def __init__(self):
    path = pathlib.Path(__file__).parent.absolute()
    self.originalDictionaryPath = str(path) + '/Dictionary/slang.txt'
    self.dictionaryPath = self.originalDictionaryPath
    self.dictionary = {}

    self.openDictionary()

  def openDictionary(self):
    dictionary = open(self.dictionaryPath, 'r')
    self.dictionary = {word.rstrip().lower().split(';')[0]: word.rstrip().lower().split(';')[1] for word in dictionary.readlines()}

  def resetDictionary(self):
    self.dictionaryPath = self.originalDictionaryPath
    self.openDictionary()

  def importDictionary(self, path):
    if not exists(path):
      raise Exception('Dictionary path not found')
    self.dictionaryPath = path
    self.openDictionary()

  def getDictionary(self):
    return self.dictionary

  def addDictionary(self, data):
    if type(data) == dict:
      dictionary = dict((key.lower(), value.lower()) for key, value in data.items())
    else:
      if not exists(data):
        raise Exception('Dictionary path not found')
      source = open(data, 'r')
      dictionary = {word.rstrip().lower().split(';')[0]: word.rstrip().lower().split(';')[1] for word in source.readlines()}

    self.dictionary.update(dictionary)

  def convertSlang(self, data):
    self.data = data
    if type(self.data) == str:
      data = self.data.split()

    result = list(filter(None, [self.dictionary[word.strip().lower()] if word.strip().lower() in self.dictionary else word for word in data]))
    return result if type(self.data) == list else ' '.join(result).strip()



import re

class CleanerTextMachine:
  def __init__(self) -> None:
      pass
  
  def cleanNumber(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub('[0-9]', ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanUrl(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub('(https://\w+.\w+/\w+)|(https://\w+.\w+)|(http://\w+.\w+/\w+)|(http://\w+.\w+)', ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanHashtag(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub('(#\w+)', ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanMention(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub('(@\w+)', ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanSymbol(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub('[\W_]', ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def deepClean(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = self.cleanUrl(text)
    result = self.cleanNumber(result)
    result = self.cleanHashtag(result)
    result = self.cleanMention(result)
    result = self.cleanSymbol(result)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanCustom(self, pattern, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    result = re.sub(pattern, ' ', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())
  
  def cleanSingleChar(self, data):
    text = data
    if type(data) == str:
      text = data.split()
    result = list(filter(None, [word.strip() if len(word) > 1 else None for word in text]))
    return result if type(data) == list else ' '.join(result)
  
  def cleanMinChar(self, data, mininumLength):
    text = data
    if type(data) == str:
      text = data.split()
    result = list(
        filter(None, [word.strip() if len(word) > mininumLength else None for word in text]))
    return result if type(data) == list else ' '.join(result)

  def cleanEmoji(self, data):
    text = data
    if type(data) == list:
      text = ' '.join(data)
    pattern = re.compile("["
                         u"\U0001F600-\U0001F64F"  # emoticons
                         u"\U0001F300-\U0001F5FF"  # symbols & pictographs
                         u"\U0001F680-\U0001F6FF"  # transport & map symbols
                         u"\U0001F1E0-\U0001F1FF"  # flags (iOS)
                         u"\U00002500-\U00002BEF"  # chinese char
                         u"\U00002702-\U000027B0"
                         u"\U00002702-\U000027B0"
                         u"\U000024C2-\U0001F251"
                         u"\U0001f926-\U0001f937"
                         u"\U00010000-\U0010ffff"
                         u"\u2640-\u2642"
                         u"\u2600-\u2B55"
                         u"\u200d"
                         u"\u23cf"
                         u"\u23e9"
                         u"\u231a"
                         u"\ufe0f"  # dingbats
                         u"\u3030"
                         "]+", flags=re.UNICODE)
    result = pattern.sub(r'', text)
    return result.split() if type(data) == list else ' '.join(result.strip().split())



from setuptools import setup, find_packages

setup(
    name='Sastrapy',
    version='0.1.9',
    description='A simple text processing for Bahasa Indonesia',
    long_description='A simple text processing for Bahasa Indonesia',
    url='https://github.com/sastrapy/sastrapy',
    author='Khoerul Umam',
    author_email='id.khoerulumam@gmail.com',
    license='MIT',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    install_requires=['pathlib'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='stopword remover tokenize slang converter text processing',
    package_data={
        '': ['Corpus/Dictionary/*.txt'],
    },
)



import pathlib
from os.path import exists


class StopwordRemoverMachine:
  def __init__(self):
    path = pathlib.Path(__file__).parent.absolute()
    self.originalDictionaryPath = str(path) + '/Dictionary/stopwords.txt'
    self.dictionaryPath = self.originalDictionaryPath
    self.dictionary = []

    self.openDictionary()

  def openDictionary(self):
    dictionary = open(self.dictionaryPath, 'r')
    self.dictionary = [word.rstrip().lower() for word in dictionary.readlines()]

  def resetDictionary(self):
    self.dictionaryPath = self.originalDictionaryPath
    self.openDictionary()

  def importDictionary(self, path):
    if not exists(path):
      raise Exception('Dictionary path not found')
    self.dictionaryPath = path
    self.openDictionary()

  def getDictionary(self):
    return self.dictionary

  def addDictionary(self, data):
    if type(data) == list:
      dictionary = [word.strip().lower() for word in data]
    else:
      if not exists(data):
        raise Exception('Dictionary path not found')
      source = open(data, 'r')
      dictionary = [word.rstrip().lower() for word in source.readlines()]
    self.dictionary = self.dictionary + dictionary

  def removeStopword(self, data):
    self.data = data
    if type(self.data) == str:
      data = self.data.split()

    result = list(filter(None, [word.strip() if word.lower() not in self.dictionary else None for word in data]))
    return result if type(self.data) == list else ' '.join(result).strip()
